==> ibm_watson_machine_learning-1.0.115-py3-none-any.whl: ibm_watson_machine_learning/tests/autoai/svt/test_iris_using_container_and_default.py <==
import unittest

import ibm_boto3

from ibm_watson_machine_learning.helpers.connections import DataConnection, ContainerLocation, S3Location
from ibm_watson_machine_learning.utils.autoai.errors import WMLClientError
from ibm_watson_machine_learning.tests.utils import bucket_exists, is_cp4d, create_bucket
from ibm_watson_machine_learning.tests.autoai.svt.abstract_test_iris_wml_autoai_multiclass_connections import (
    AbstractTestAutoAIRemote)


@unittest.skipIf(is_cp4d(), "Supported only on CLOUD")
class TestAutoAIRemote(AbstractTestAutoAIRemote, unittest.TestCase):
    """
    The test can be run on CLOUD
    The test covers:
    - COS connection set-up
    - Saving data `iris.csv` to s3 connection
    - downloading training data from connection
    - downloading all generated pipelines to lale pipeline
    - deployment with lale pipeline
    - deployment deletion
    Connection used in test:
     - input: S3 connection pointing to COS.
     - output: ConnectedDataAsset pointing to COS.
    """

    # def test_00b_prepare_COS_instance(self):
    #     cos_resource = ibm_boto3.resource(
    #         service_name="s3",
    #         endpoint_url=self.cos_endpoint,
    #         aws_access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
    #         aws_secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']
    #     )
    #     # Prepare bucket
    #     if not bucket_exists(cos_resource, self.bucket_name):
    #         TestAutoAIRemote.bucket_name = create_bucket(cos_resource, self.bucket_name)
    #
    #         self.assertIsNotNone(TestAutoAIRemote.bucket_name)
    #         self.assertTrue(bucket_exists(cos_resource, TestAutoAIRemote.bucket_name))
    #
    #     print(f"Using COS bucket: {TestAutoAIRemote.bucket_name}")

    # def test_00c_prepare_connection_to_COS(self):
    #     connection_details = self.wml_client.connections.create({
    #         'datasource_type': self.wml_client.connections.get_datasource_type_uid_by_name('bluemixcloudobjectstorage'),
    #         'name': 'Connection to COS for tests',
    #         'properties': {
    #             'bucket': self.bucket_name,
    #             'access_key': self.cos_credentials['cos_hmac_keys']['access_key_id'],
    #             'secret_key': self.cos_credentials['cos_hmac_keys']['secret_access_key'],
    #             'iam_url': self.wml_client.service_instance._href_definitions.get_iam_token_url(),
    #             'url': self.cos_endpoint
    #         }
    #     })

        # TestAutoAIRemote.connection_id = self.wml_client.connections.get_uid(connection_details)
        # self.assertIsInstance(self.connection_id, str)

    def test_00d_write_data_to_container(self):
        # note writing to project
        pass

    def test_02_DataConnection_setup(self):
        TestAutoAIRemote.data_connection = DataConnection(
            location=ContainerLocation(path=self.data_cos_path
                                       ))

        TestAutoAIRemote.results_connection = None
        # TestAutoAIRemote.data_connection.write(data=self.data_location, remote_name=self.data_cos_path)

        self.assertIsNotNone(obj=TestAutoAIRemote.data_connection)

    def test_02a_read_saved_remote_data_before_fit(self):
        pass

    def test_29_delete_connection_and_connected_data_asset(self):
        self.wml_client.connections.delete(self.connection_id)

        with self.assertRaises(WMLClientError):
            self.wml_client.connections.get_details(self.connection_id)


if __name__ == '__main__':
    unittest.main()

==> ibm_watson_machine_learning-1.0.165-py3-none-any.whl: ibm_watson_machine_learning/tests/autoai/svt/test_iris_using_container_and_default.py <==
import unittest

import ibm_boto3

from ibm_watson_machine_learning.helpers.connections import DataConnection, ContainerLocation, S3Location
from ibm_watson_machine_learning.utils.autoai.errors import WMLClientError
from ibm_watson_machine_learning.tests.utils import bucket_exists, is_cp4d, create_bucket, save_data_to_container
from ibm_watson_machine_learning.tests.autoai.abstract_tests_classes import (
    AbstractTestAutoAIRemote)


@unittest.skipIf(is_cp4d(), "Supported only on CLOUD")
class TestAutoAIRemote(AbstractTestAutoAIRemote, unittest.TestCase):
    """
    The test can be run on CLOUD
    The test covers:
    - COS connection set-up
    - Saving data `iris.csv` to s3 connection
    - downloading training data from connection
    - downloading all generated pipelines to lale pipeline
    - deployment with lale pipeline
    - deployment deletion
    Connection used in test:
     - input: S3 connection pointing to COS.
     - output: ConnectedDataAsset pointing to COS.
    """

    def test_00d_write_data_to_container(self):
        # writing to project
        self.wml_client.set.default_project(self.project_id)
        save_data_to_container(self.data_location, self.data_cos_path, self.wml_client)

    def test_02_DataConnection_setup(self):
        TestAutoAIRemote.data_connection = DataConnection(
            location=ContainerLocation(path=self.data_cos_path
                                       ))

        TestAutoAIRemote.results_connection = None
        # TestAutoAIRemote.data_connection.write(data=self.data_location, remote_name=self.data_cos_path)

        self.assertIsNotNone(obj=TestAutoAIRemote.data_connection)

    def test_02a_read_saved_remote_data_before_fit(self):
        pass


if __name__ == '__main__':
    unittest.main()
